@@ -1,5 +1,8 @@
 #!/bin/sh
-. /etc/platform.conf
+
+[ -f /etc/platform.conf ] && source /etc/platform.conf
+[ -f /etc/profile.d/40_otu_platform.sh ] && source /etc/profile.d/40_otu_platform.sh
+
 echo "<?xml version='1.0' encoding='UTF-8'?>
 <device>
     <service id='deviced'>
