@@ -3,6 +3,8 @@
 alias showlog='tac /var/log/user.log | grep -B 10000 -m 1 "Isu: \[PINFO\]   1 ." | tac'
 alias is_rescue='[ -f /proc/device-tree/board/rescue-mode ] && echo $(cat /proc/device-tree/board/rescue-mode) || echo "no"'
 
+alias ls='ls --color="auto"'
+alias ll='ls -lAh'
 
 source /usr/lib/otu_functions
 
