@@ -11,6 +11,50 @@
 #
 
 source /usr/lib/otu_functions
+source /etc/profile.d/40_otu_platform.sh
+source /etc/otu/otuparts.sh
+
+inspect_repair_unused_prtn() {
+    #
+    #  fsck error codes 4, 8, 12 and 128 indicate a corrupted partition
+    EC_CODE_4=4
+    EC_CODE_8=8
+    EC_CODE_12=12
+    EC_CODE_128=128
+    
+    #
+    #  Use fsck to inspect partition
+    #  Options -f -n runs a check without running repairs.
+    #  Recover only for fsck error codes "4" and "128"
+    umount "$ALT_PART" 2>/dev/null
+    res_scan_check=$(fsck -f -n -M "$ALT_PART")
+    fsck_rc=$?
+    otu_log $0 "Checking $ALT_PART ::  fsck error code = $fsck_rc ."
+
+    case $fsck_rc in
+        $EC_CODE_4 | $EC_CODE_8 | $EC_CODE_12 | $EC_CODE_128)
+            #
+            #  Unused partion is not sane.
+            #  Recover device partition within capabilities of fsck.
+            #
+            otu_log $0 "Device $ALT_PART contains partition errors :: Initiating fsck recovery."
+	          fsck -f -y $ALT_PART
+            if [[ $? -eq 0 || $? -eq 1 ]]; then
+                mount $ALT_PART /mnt/fs/unused_part  2>/dev/null
+	              otu_log $0 "Recovery complete for device $ALT_PART ::  fsck repair return code = $?"
+            else
+	              otu_log $0 "Unable to repair $ALT_PART ::  fsck repair return code = $? ::  $ALT_PART is not mounted."
+            fi
+	      ;;
+
+        *)
+            #
+            # Recovery procedure is not necessary
+            #
+            otu_log $0 "Partition recovery is NOT required for device $ALT_PART ."
+        ;;
+        esac
+}
 
 # If we are not Otu but /otu directory exists remove it (otu5000 to eotdrv2 conversion by manufacturing)
 is_cotu_hw
@@ -22,13 +66,15 @@ SW_OTU=$?
 # Do the rest only if using otu
 quit_if_not_using_otu
 
-# Create /acterna/user directory (temporary we have to remove this directory and use /user instead)
-if [ ! -d /acterna/user ] ; then
-        mkdir /acterna/user
-fi
-if [ ! -d /acterna/user/disk ] ; then
-        mount --rbind /user /acterna/user
+#
+#  In OTU rescue mode only, check if unused partition
+#  is corrupted and recover if possible.
+#
+if [[ "$(is_rescue)" == "yes" ]]; then
+    otu_log $0 " . OTU is in rescue mode; inspecting $unused_prtn_device if partition is sane."
+    inspect_repair_unused_prtn
 fi
+#
 
 # Create /Otu directory
 if [ ! -L /otu ] ;  then
@@ -68,19 +114,16 @@ if [ ! -f /acterna/release/bin/Otu.ver ] && [ -f /etc/acterna/Otu.ver ] ; then
 fi
 
 # In enhance security mode we have to check every boot that users have not been added during an upgrade
-if [ "$(/sbin/fw_printenv -n Enhanced_Security)" = "true" ] ; then
+if [ "$(fw_printenv -n Enhanced_Security)" = "true" ] ; then
     bash /usr/lib/jdsu/scripts/update_user_list.sh "DEL" > /dev/null 2>&1
 fi
 
 # Log partition we are using in otu log
 if [ -d /otu/log ] ; then
-    source /etc/otu/otuparts.sh
     CURRENT_DATE=$(date '+%Y-%m-%d %H:%M:%S.%3N')
     echo "${CURRENT_DATE} : Boot using partition ${CURRENT_PART}" >> /otu/log/boot.log
-    if [ -f /proc/device-tree/board/rescue-mode ] && [ $(cat /proc/device-tree/board/rescue-mode) == "yes" ] ; then
+    if [[ "$(is_rescue)" == "yes" ]] ; then
         echo "${CURRENT_DATE} : Started in rescue mode" >> /otu/log/boot.log
-        # We want to try again to boot normally at next reboot
-        otu_confirm_start.sh
     fi
 fi
 
