@@ -157,12 +157,12 @@ class SMTContext
      * Destroy running session if it exists.
      *
      */
-    function closeSession()
+    function closeSession($cause)
     {
         //don't check timeout when closing a session
         $session = $this->getSessionContext( FALSE );
         $session->setUser( NULL );
-        $session->closeSession();
+        $session->closeSession($cause);
         
         //cleanup options at logout
         SMTSmartOtuSettings::setOtuOption(NULL);
