@@ -76,6 +76,13 @@ class SMTOtuApi
      */
     const SNMP_MEDIA = 'SNMP';
     
+    /**
+     * SNMPV3 media.
+     *
+     * @var string
+     */
+    const SNMPV3_MEDIA = 'SNMPV3';
+    
     /**
      * Only one SNMP config
      * @var integer
@@ -393,6 +400,8 @@ class SMTOtuApi
     {
     	return sprintf( self::CMD_get_MOD_Name, $moduleId );
     }
+
+    const CMD_get_DWDM_MOD = 'OTU:WDM:MOD?';
     
     const CMD_check_module_compatibility_with_switch = 'OTU:MODU:SWITCH:COMP?';
     //modems configuration:
@@ -648,7 +657,39 @@ class SMTOtuApi
      */
     const CMD_test_snmp = 'OTU:ALE:SNMP:TEST %d,"%s","%s",%d,"%s"';
     
+    /**
+     * SNMP index (1 uniquement)
+     */
+    const CMD_get_snmpv3_conf = 'OTU:ALE:V3SNMP:GET? %d';
+    /**
+     * #config=1//SNMPServerAddress//SNMPUser//port SNMP
+     */
+    const CMD_set_snmpv3_conf = 'OTU:ALE:V3SNMP:SET %d,"%s","%s",%d,"%s","%s","%s","%s"';
+    /**
+     * #config=1//SNMPServerAddress//SNMPCommunity//port SNMP//message
+     */
+    const CMD_test_snmpv3 = 'OTU:ALE:V3SNMP:TEST %d,"%s","%s",%d,"%s","%s","%s","%s","%s"';
+    static function getSnmpV3Command($snmpIndex)
+    {
+        return sprintf( self::CMD_get_snmpv3_conf, $snmpIndex );
+    }
     
+    const CMD_get_SNMP_Support = 'OTU:MEDIA:SUPPORT? ALT3';
+    const CMD_set_SNMP_Support = 'OTU:MEDIA:SUPPORT ALT3,%s';
+    
+    /**
+     *
+     * @param integer $snmpIndex
+     * @param string $serverAddress
+     * @param string $user
+     * @param integer $port
+     *
+     * @return string
+     */
+    static function setSnmpV3Command( $snmpIndex, $serverAddress, $user, $port, $authType, $authPassword, $encryptType, $encryptPassword )
+    {
+        return sprintf( self::CMD_set_snmpv3_conf, $snmpIndex, $serverAddress, $user, $port, $authType, $authPassword, $encryptType, $encryptPassword);
+    }
     /**
      * Web service index (1 uniquement)
      */
@@ -689,10 +730,24 @@ class SMTOtuApi
     	return sprintf( self::CMD_test_snmp, self::SNMP_INDEX, $serverAddress, $community, $port, $message);
     }
     
+    /**
+     *
+     * @param string $serverAddress
+     * @param string $user
+     * @param integer $port
+     * @param string $message //30 characters
+     *
+     * @return string
+     */
+    static function testSnmpV3Command( $serverAddress, $user, $port, $authType, $authPassword, $encryptType, $encryptPassword, $message )
+    {
+        return sprintf( self::CMD_test_snmpv3, self::SNMP_INDEX, $serverAddress, $user, $port, $authType, $authPassword, $encryptType, $encryptPassword, $message);
+    }
+    
     const CMD_set_domain = 'OTU:SYSTEM:COM:DOMAIN "%s"';
     const CMD_set_site = 'OTU:SYSTEM:COM:SITE "%s"';
     /**
-     * ALT2 or ALT1
+     * ALT3
      */
     const CMD_get_media = 'OTU:MEDIA:SNMP:GET? %s';
     
@@ -813,12 +868,12 @@ class SMTOtuApi
      *
      * @return string
      */
-    static function setSNMPMedia( $on )
+    static function setSNMPMedia( $on, $snmpV3 )
     {
     	$snmpStatusCommand = NULL;
     	if ( $on )
     	{
-    		$snmpStatusCommand = sprintf( self::CMD_set_media, self::MEDIA_3, self::SNMP_MEDIA, 'ETH0', self::RES_NONE, self::RES_NONE, self::RES_NONE, self::RES_ALL, 10, self::MEDIA_RETRY_DELAY  );//the last 2 parameters are not used
+    	    $snmpStatusCommand = sprintf( self::CMD_set_media, self::MEDIA_3, $snmpV3? self::SNMPV3_MEDIA: self::SNMP_MEDIA, 'ETH0', self::RES_NONE, self::RES_NONE, self::RES_NONE, self::RES_ALL, 10, self::MEDIA_RETRY_DELAY  );//the last 2 parameters are not used
     	}
     	else
     	{
@@ -1023,7 +1078,11 @@ class SMTOtuApi
     const CMD_get_switch_config_type = 'OTU:SWITCH:CONFIG:TYPE? %d'; //OSX_JDSU, MOLEX
     const CMD_Has_Internal_Switch_License = 'OTU:SWITCH:LIC:INTValid?';
     const CMD_Get_Internal_Switch_Total_Ports = 'OTU:SWITCH:CONFIG:INTOutputs?';
-        
+    
+    //HDOS
+    const CMD_Has_HDOS_Switch_License = 'OTU:SWITCH:LIC:UOSValid?';
+    const CMD_Get_HDOS_Switch_Total_Ports = 'OTU:SWITCH:CONFIG:UOSOutputs?';
+    
     //OTAU NEW FUNCTIONS to handle big configurations of ROTAUs
     const CMD_compare_switches = 'OTU:SWITCH:COMPAR:MACRO? %d';//0/1... for Macroswitchid, returns SAME,DIFF,MISSCONF,MISSDET
     const CMD_compare_switches_result = 'OTU:SWITCH:COMPAR:RESULT? %d';//0/1... for Macroswitchid, returns SAME,DIFF,MISSCONF,MISSDET
@@ -1052,6 +1111,8 @@ class SMTOtuApi
     const CMD_remove_dmux = 'OTU:WDM:DEL %d';// 1 DMUX position
     const CMD_add_dmux = 'OTU:WDM:ADD? "%s",%d,%s';// 1 DMUX position, Name, Outputs, Channel
     const CMD_update_dmux = 'OTU:WDM:CHANGE %d,"%s",%d,%s';// 1 DMUX position, Name, Outputs, Channel
+    const CMD_set_initial_frequency = 'OTU:WDM:CALIBRATION:FREQUENCY %d';// 196100
+    const CMD_get_initial_frequency = 'OTU:WDM:CALIBRATION:FREQUENCY?';// 196100
     
     //****************
     //* measurement
@@ -2277,6 +2338,18 @@ class SMTOtuApi
     {
         return self::CMD_otu_get_PAYG_internal_switch_lic_count;
     }
+
+    const CMD_otu_get_PAYG_HDOS_switch_lic_count = "OTU:SWITCH:LIC:UOSCount?";
+    
+    /**
+     * OTU COMMAND
+     *
+     * @return integer number of PYG license count for HDOS switch
+     */
+    static function getOtu_PAYG_HDOS_Switch_Lic_Count()
+    {
+        return self::CMD_otu_get_PAYG_HDOS_switch_lic_count;
+    }
     
     /**
      * OTU COMMAND
@@ -2404,6 +2477,7 @@ class SMTOtuApi
     const CMD_get_Otdr_LICENSE = "ISU:LIC:LIST? \"Otdr\"";
     const CMD_get_SAA_LICENSE = "ISU:LIC:LIST? \"Anywhere\"";
     const CMD_get_OTAU_LICENSE = "ISU:LIC:LIST? \"Otau\"";
+    const CMD_get_HDOS_LICENSE = "ISU:LIC:LIST? \"HDOS\"";
     
     /**
      * WARNING ISU COMMAND
@@ -2432,7 +2506,15 @@ class SMTOtuApi
     {
         return self::CMD_get_OTAU_LICENSE;
     }
-    
+    /**
+     * WARNING ISU COMMAND
+     *
+     * @return string
+     */
+    static function getHdosLicensesFromIsu()
+    {
+        return self::CMD_get_HDOS_LICENSE;
+    }
     /**
      * WARNING ISU COMMAND
      *
