@@ -69,7 +69,7 @@ class SMTApiOtuService extends SMTService implements SMTIService
 			SMTHttpResponse::handleApiError($this->getContext(), SMTRestException::INTERNAL_SERVER_ERROR, SMTApiDto::FAILURE, 'Failed to retrieve otu info');
 		}
 
-		$this->getContext()->closeSession();
+		$this->getContext()->closeSession('api');
 		
 		return $otuDto->getJsonData();
 	}
@@ -124,9 +124,9 @@ class SMTApiOtuService extends SMTService implements SMTIService
 		}
 		catch (\Exception $e)
 		{
-			$this->getContext()->getLogger()->traceException($ex);
+			$this->getContext()->getLogger()->traceException($e);
 		}
-		$this->getContext()->closeSession();
+		$this->getContext()->closeSession('api');
 		
 		return $dateDto->getJsonData();
 	}
@@ -179,7 +179,7 @@ class SMTApiOtuService extends SMTService implements SMTIService
 			SMTHttpResponse::handleApiError($this->getContext(), SMTRestException::INTERNAL_SERVER_ERROR, SMTApiDto::FAILURE, 'Failed to retrieve snmp info');
 		}
 		
-		$this->getContext()->closeSession();
+		$this->getContext()->closeSession('api');
 		
 		return $snmpListDto->getJsonData();
 	}
@@ -250,7 +250,7 @@ class SMTApiOtuService extends SMTService implements SMTIService
 			SMTHttpResponse::handleApiError($this->getContext(), SMTRestException::INTERNAL_SERVER_ERROR, SMTApiDto::FAILURE, 'Failed to retrieve snmp ImAlive trap info');
 		}
 		
-		$this->getContext()->closeSession();
+		$this->getContext()->closeSession('api');
 		
 		return $snmpImAliveDto->getJsonData();
 	}
@@ -339,7 +339,7 @@ class SMTApiOtuService extends SMTService implements SMTIService
 			$this->getContext()->getLogger()->traceException($ex);
 			SMTHttpResponse::handleApiError( $this->getContext(), SMTRestException::INTERNAL_SERVER_ERROR, SMTApiDto::FAILURE, 'Failed to send SNMP test trap');
 		}
-		$this->getContext()->closeSession();
+		$this->getContext()->closeSession('api');
 		return $testStatusDto->getJsonData();
 	}
 	
@@ -372,7 +372,7 @@ class SMTApiOtuService extends SMTService implements SMTIService
 			SMTHttpResponse::handleApiError($this->getContext(), SMTRestException::INTERNAL_SERVER_ERROR, SMTApiDto::FAILURE, 'Failed to retrieve otu info');
 		}
 		
-		$this->getContext()->closeSession();
+		$this->getContext()->closeSession('api');
 		
 		return $opticalModuleDto->getJsonData();
 	}
@@ -391,7 +391,7 @@ class SMTApiOtuService extends SMTService implements SMTIService
 		$ipv4Dto = new SMTApiIpv4Dto();
 		try
 		{
-			$ipInfo = $this->sendReceive( SMTOtuApi::getIpv4Config() );
+			$ipInfo = $this->sendReceive( SMTOtuApi::getIpv4Config('ETH0') );
 			list( $dhcp, $ip, $subnet, $dns, $domainName, $gateway ) = explode(",", $ipInfo);
 			
 			$ipv4Dto->setDhcp( trim($dhcp) );
@@ -407,11 +407,46 @@ class SMTApiOtuService extends SMTService implements SMTIService
 			SMTHttpResponse::handleApiError($this->getContext(), SMTRestException::INTERNAL_SERVER_ERROR, SMTApiDto::FAILURE, 'Failed to retrieve otu IPv4 setup');
 		}
 		
-		$this->getContext()->closeSession();
+		$this->getContext()->closeSession('api');
 		
 		return $ipv4Dto->getJsonData();
 	}
 
+	/**
+	 *
+	 * @url GET /ipv4backup
+	 *
+	 * @access protected
+	 * @class SMTAccessControl {@requires install}
+	 */
+	function getIpv4Backup()
+	{
+	    $this->checkApi();
+	    
+	    $ipv4Dto = new SMTApiIpv4Dto();
+	    try
+	    {
+	        $ipInfo = $this->sendReceive( SMTOtuApi::getIpv4Config('ETH1') );
+	        list( $dhcp, $ip, $subnet, $dns, $domainName, $gateway ) = explode(",", $ipInfo);
+	        
+	        $ipv4Dto->setDhcp( trim($dhcp) );
+	        $ipv4Dto->setIp( trim($ip) );
+	        $ipv4Dto->setSubnet( trim($subnet));
+	        $ipv4Dto->setDns(trim($dns));
+	        $ipv4Dto->setDomain(trim($domainName));
+	        $ipv4Dto->setGateway(trim($gateway));
+	    }
+	    catch ( \Exception $e )
+	    {
+	        $this->getContext()->getLogger()->traceException($e);
+	        SMTHttpResponse::handleApiError($this->getContext(), SMTRestException::INTERNAL_SERVER_ERROR, SMTApiDto::FAILURE, 'Failed to retrieve otu IPv4 backup setup');
+	    }
+	    
+	    $this->getContext()->closeSession('api');
+	    
+	    return $ipv4Dto->getJsonData();
+	}
+	
 	/**
 	 *
 	 * @url GET /ipv6
@@ -426,7 +461,7 @@ class SMTApiOtuService extends SMTService implements SMTIService
 		$ipv6Dto = new SMTApiIpv6Dto();
 		try
 		{
-			$ipInfo = $this->sendReceive( SMTOtuApi::getIpv6Config() );
+			$ipInfo = $this->sendReceive( SMTOtuApi::getIpv6Config('ETH0') );
 			list( $active, $dhcp, $ip, $gateway, $site, $dns, $link ) = explode(",", $ipInfo);
 			
 			$ipv6Dto->setActive( trim($active) );
@@ -444,10 +479,46 @@ class SMTApiOtuService extends SMTService implements SMTIService
 			SMTHttpResponse::handleApiError($this->getContext(), SMTRestException::INTERNAL_SERVER_ERROR, SMTApiDto::FAILURE, 'Failed to retrieve otu IPv6 setup');
 		}
 		
-		$this->getContext()->closeSession();
+		$this->getContext()->closeSession('api');
 		
 		return $ipv6Dto->getJsonData();
 	}
+	/**
+	 *
+	 * @url GET /ipv6backup
+	 *
+	 * @access protected
+	 * @class SMTAccessControl {@requires install}
+	 */
+	function getIpv6Backup()
+	{
+	    $this->checkApi();
+	    
+	    $ipv6Dto = new SMTApiIpv6Dto();
+	    try
+	    {
+	        $ipInfo = $this->sendReceive( SMTOtuApi::getIpv6Config('ETH1') );
+	        list( $active, $dhcp, $ip, $gateway, $site, $dns, $link ) = explode(",", $ipInfo);
+	        
+	        $ipv6Dto->setActive( trim($active) );
+	        $ipv6Dto->setDhcp( trim($dhcp) );
+	        $ipv6Dto->setIp( trim($ip) );
+	        $ipv6Dto->setGateway(trim($gateway));
+	        $ipv6Dto->setSite( trim($site));
+	        $ipv6Dto->setDns(trim($dns));
+	        $ipv6Dto->setLinkIp(trim($link));
+	        
+	    }
+	    catch ( \Exception $e )
+	    {
+	        $this->getContext()->getLogger()->traceException($e);
+	        SMTHttpResponse::handleApiError($this->getContext(), SMTRestException::INTERNAL_SERVER_ERROR, SMTApiDto::FAILURE, 'Failed to retrieve otu IPv6 backup setup');
+	    }
+	    
+	    $this->getContext()->closeSession('api');
+	    
+	    return $ipv6Dto->getJsonData();
+	}
 	
 	/**
 	 *
@@ -471,7 +542,7 @@ class SMTApiOtuService extends SMTService implements SMTIService
 			$this->getContext()->getLogger()->traceException($e);
 			SMTHttpResponse::handleApiError($this->getContext(), SMTRestException::BAD_REQUEST, SMTApiDto::FAILURE, 'failed to clear all OTU alarms  ');
 		}
-		$this->getContext()->closeSession();
+		$this->getContext()->closeSession('api');
 		
 		return $statusDto->getJsonData();
 	}
@@ -524,7 +595,7 @@ class SMTApiOtuService extends SMTService implements SMTIService
 			SMTHttpResponse::handleApiError( $this->getContext(), SMTRestException::BAD_REQUEST, SMTApiDto::FAILURE, 'Invalid credentials');
 		}
 
-		$this->getContext()->closeSession();
+		$this->getContext()->closeSession('api');
 		
 		return $statusDto->getJsonData();
 	}
@@ -569,7 +640,7 @@ class SMTApiOtuService extends SMTService implements SMTIService
 			SMTHttpResponse::handleApiError( $this->getContext(), SMTRestException::BAD_REQUEST, SMTApiDto::FAILURE, 'Invalid credentials');
 		}
 		
-		$this->getContext()->closeSession();
+		$this->getContext()->closeSession('api');
 		
 		return $statusDto->getJsonData();
 	}
@@ -605,7 +676,7 @@ class SMTApiOtuService extends SMTService implements SMTIService
 			$this->getContext()->getLogger()->traceException($e);
 			SMTHttpResponse::handleApiError( $this->getContext(), SMTRestException::BAD_REQUEST, SMTApiDto::FAILURE, 'Failed to retrieve guest user');
 		}
-		$this->getContext()->closeSession();
+		$this->getContext()->closeSession('api');
 		
 		return $userToSend->getJsonData();
 	}
@@ -635,7 +706,7 @@ class SMTApiOtuService extends SMTService implements SMTIService
 			SMTHttpResponse::handleApiError( $this->getContext(), SMTRestException::BAD_REQUEST, SMTApiDto::FAILURE, 'Failed to enable/disable guest user');
 		}
 		
-		$this->getContext()->closeSession();
+		$this->getContext()->closeSession('api');
 		
 		return $statusDto->getJsonData();
 	}
