@@ -386,11 +386,20 @@ class SMTLicence extends SMTServiceHelper
             //retrieve connection from the socket manager
             $socket = $socketManager->openSocket( SMTOtuSocket::ISU_PORT );
             $softwareOptions = $socket->sendReceive(SMTOtuApi::getOtuLicensesFromIsu(), 10);
-            if (SMTOtuType::isOTH() || SMTOtuType::isOtu8KV2() || SMTOtuType::isMts8KV2())
+            if (SMTOtuType::isOTH() || SMTOtuType::isOtu8KV2())
             {
             $softwareOptions = $softwareOptions.",".$socket->sendReceive(SMTOtuApi::getOtauLicensesFromIsu());
             $softwareOptions = $softwareOptions.",".$socket->sendReceive(SMTOtuApi::getOtdrLicensesFromIsu());
             $softwareOptions = $softwareOptions.",".$socket->sendReceive(SMTOtuApi::getSensingLicensesFromIsu());
+            if (SMTOtuType::isOTH() )
+               {
+               $softwareOptions = $softwareOptions.",".$socket->sendReceive(SMTOtuApi::getHdosLicensesFromIsu());
+               }
+            }
+            else if (SMTOtuType::isFTH7K() )
+            {
+                $softwareOptions = $softwareOptions.",".$socket->sendReceive(SMTOtuApi::getHdosLicensesFromIsu());
+                $softwareOptions = $softwareOptions.",".$socket->sendReceive(SMTOtuApi::getOtdrLicensesFromIsu());
             }
             else if (SMTOtuType::isCOtu_EOTDRV2())
             {
@@ -412,7 +421,10 @@ class SMTLicence extends SMTServiceHelper
 	            		$softwareOptions = $saaOption;
 	            	}
             	}
+            	
+            	$softwareOptions = $softwareOptions.",".$socket->sendReceive(SMTOtuApi::getHdosLicensesFromIsu());
             }
+            $softwareOptions = trim( str_replace(',,',',', $softwareOptions) );
             $softwareOptions = trim( str_replace(',',' ', $softwareOptions) );
             
             SMTLogger::getInstance()->trace(sprintf("software options: %s", $softwareOptions) );
@@ -452,7 +464,6 @@ class SMTLicence extends SMTServiceHelper
     			{
 	    			$status = $context->getOtuSocket()->sendReceive( SMTOtuApi::getOtu_Option_Status($option) );
 	    			
-	    			//$name = $context->getOtuSocket()->sendReceive( SMTOtuApi::getOtu_Option_Name($option) );
 	    			$payg_license_count = self::getPayg_Option_Value( $context, $option, $status );
 	    			$license = new SMTLicenseDto();
 	    			$license->setSoftwareOption($option);
@@ -489,13 +500,27 @@ class SMTLicence extends SMTServiceHelper
     static function getPayg_Option_Value( SMTContext $context, $option, $status )
     {
         $optionValue = 0;
-        if ( !SMTOtuType::isCOtu_EOTDRV2() && strcmp($status, 'IMPOSSIBLE') !=0 )
+        if ( strcmp($status, 'IMPOSSIBLE') !=0 )
         {
-            if ( strcasecmp( $option, SMTLicenseList::OTU_OPTION_PAYG_PORT12) == 0)
+            if (!SMTOtuType::isCOtu_EOTDRV2() && !SMTOtuType::isFTH7K())
+            {
+                if ( strcasecmp( $option, SMTLicenseList::OTU_OPTION_PAYG_PORT12) == 0)
+                {
+                    try
+                    {
+                        $optionValue = intval($context->getOtuSocket()->sendReceive( SMTOtuApi::getOtu_PAYG_Internal_Switch_Lic_Count()) );                    
+                    }
+                    catch ( \Exception $e )
+                    {
+                        SMTLogger::getInstance()->traceException( $e );
+                    }
+                }
+            }
+            if ( strcasecmp( $option, SMTLicenseList::OTU_OPTION_PAYG_HDOS12) == 0)
             {
                 try
                 {
-                    $optionValue = intval($context->getOtuSocket()->sendReceive( SMTOtuApi::getOtu_PAYG_Internal_Switch_Lic_Count()) );                    
+                    $optionValue = intval($context->getOtuSocket()->sendReceive( SMTOtuApi::getOtu_PAYG_HDOS_Switch_Lic_Count()) );
                 }
                 catch ( \Exception $e )
                 {
@@ -503,7 +528,7 @@ class SMTLicence extends SMTServiceHelper
                 }
             }
         }
-        return $optionValue;        
+        return $optionValue;
     }
 }
 ?>
