@@ -97,21 +97,8 @@ class SMTEmail extends SMTServiceHelper
 		$emailDto = new SMTEmailDto();
 		$emailDto->setValid( FALSE);
 		$hostName = $this->sendReceive( SMTOtuApi::CMD_get_otu_name );
-		$asciiName = $hostName;
-			
-		if ( !utf8_is_ascii( $hostName ) )
-		{
-			//turn latin characters with accents to ascii equivalent
-			$asciiName = utf8_accents_to_ascii( $hostName );
-				
-			//if asciiName is not an ascii string, strip non ascii characters and controls
-			if ( !utf8_is_ascii( $asciiName ) )
-			{
-				$asciiName = utf8_strip_non_ascii_ctrl($asciiName);
-			}
-		}
-		// Removes all special chars
-		$asciiName = preg_replace('/[^A-Za-z0-9\_\.\-]/', '', $asciiName);
+		
+		$asciiName = SMTUtil::convertToAscii($hostName );
 		
 		$emailDto->setAddressFrom( $asciiName.self::DEFAULT_JDSU_VIAVI_EXTENSION );
 		//Language for OTU alerts is limited to english; don't retrieve the "Alarm" string from resources.
