@@ -82,7 +82,7 @@ class SMTRotauSwitchConf extends SMTMacroSwitch
      * @param $detected boolean Whether the switch is detected or retrieved from configuration
      *
      */
-    protected function buildSwitchDto()
+    protected function buildSwitchDto($detected)
     {
     	//if global switch decoder exists (case of detection), set it in the dto.
     	$decoder = $this->getSwitchDecoder( self::GLOB );
