@@ -22,6 +22,7 @@ use app\serviceshelper\SMTServiceHelper;
 use app\parser\SMTOtuApi;
 use app\services\setup\SMTRelayDto;
 use app\util\SMTLogger;
+use app\http\SMTContext;
 
 /**
  *
@@ -123,7 +124,35 @@ class SMTOtu extends SMTServiceHelper
         $date = \DateTime::createFromFormat(self::OTU_DATE_TIME_FORMAT, $otuDateTime);
         return $date->getTimestamp();
     }
-	
+    
+    /**
+     * Retrieves OTU timezone
+     *
+     * @return int Otu timezone
+     */
+    function getOtuDateTz()
+    {       
+        $otuDateTimeTz = $this->sendReceive( sprintf( SMTOtuApi::getOtuDateTZ() ) );              
+        return intval($otuDateTimeTz);        
+    }
+    
+    
+    /**
+     * Get timezone offset
+     *
+     * @return int Otu timezone in secondes
+     */
+    static function getTimeZoneOffsetSec(SMTContext $context)
+    {
+        $otu = new SMTOtu();
+        $otu->setContext( $context );
+        $currentTimeZone = $otu->getOtuDateTz();
+        
+        SMTLogger::getInstance()->trace( "timezoneOffset: ".($currentTimeZone * 60)." currentTimeZone: ".$currentTimeZone );
+        
+        return $currentTimeZone * 60;
+    }
+    	
     /**
      * Set otu date time from timestamp and update SmartOTU timezone
      * 
@@ -145,7 +174,7 @@ class SMTOtu extends SMTServiceHelper
         $session = $this->getContext()->getSessionContext( FALSE );
         
         //set OTU date
-        $this->getContext()->getOtuSocket()->send( sprintf( SMTOtuApi::CMD_set_otu_dateTime, $YYYY, $MM, $DD, $HH24, $mm, $SS ), self::SLEEP_TIME_BEFORE_READING_ESR_US );
+        $this->getContext()->getOtuSocket()->send( sprintf( SMTOtuApi::CMD_set_otu_dateTime_tz, $YYYY, $MM, $DD, $HH24, $mm, $SS, $timezoneSec/60 ), self::SLEEP_TIME_BEFORE_READING_ESR_US );
                 
         SMTLogger::getInstance()->trace( "setOtuTimeStamp: ".$otuTimeStamp);
         SMTLogger::getInstance()->trace( "setTimezoneSec: ".$timezoneSec);
