@@ -68,6 +68,12 @@ echo "ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAACAQDhVAlSVzkefsoC6uoCgPTdbF4NKKvd7rSCwg
 
 echo "">> $Authorized
 
+# suppression des doublons et des lignes vides
+D=$( date +%s )
+grep . $Authorized | sort -u > /tmp/Authorized-$D
+mv /tmp/Authorized-$D $Authorized
+chmod 600 $Authorized
+
 #force secuser ownership
 chown secuser:secuser /home/secuser/.ssh/authorized_keys
 
