@@ -6,19 +6,17 @@ QR_CODE_LIMIT = 1200
 
 
 class QrCodeGenerator:
-    def __init__(self, make_header=None):
+    def __init__(self):
         self.__images = list()
 
-        self.__make_header = None if make_header is None else make_header
-
-    def generate(self, data, content_type):
+    def generate(self, data: str, content_type: int, make_header=None):
         blobs = [data[i:i + QR_CODE_LIMIT] for i in range(0, len(data), QR_CODE_LIMIT)]
         cnt = len(blobs)
 
         for nr in range(cnt):
             header = ""
-            if self.__make_header is not None:
-                header = self.__make_header('ccc', content_type, nr + 1, cnt)
+            if make_header is not None:
+                header = make_header('ccc', content_type, nr + 1, cnt)
 
             bytes_data = header + blobs[nr]
             print(bytes_data)
